netapp_ontap.resources.fcp_service API documentation
Description: Copyright &copy; 2020 NetApp Inc. All rights reserved …

# Module `netapp_ontap.resources.fcp_service`

Copyright © 2020 NetApp Inc. All rights reserved.

## Overview

A Fibre Channel Protocol (FC Protocol) service defines the properties of the FC Protocol target for an SVM. There can be at most one FC Protocol service for an SVM. An SVM FC Protocol service must be created before FC Protocol initiators can log in to the SVM.
The FC Protocol service REST API allows you to create, update, delete, and discover FC services for SVMs.

## Performance monitoring

Performance of the SVM can be monitored by the `metric.*` and `statistics.*` properties. These show the performance of the SVM in terms of IOPS, latency, and throughput. The `metric.*` properties denote an average whereas `statistics.*` properties denote a real-time monotonically increasing value aggregated across all nodes.

## Examples

### Creating an FC Protocol service for an SVM

The simplest way to create an FC Protocol service is to specify only the SVM, either by name or UUID. By default, the new FC Protocol service is enabled.
In this example, the `return_records` query parameter is used to retrieve the new FC Protocol service object in the REST response.

    from netapp_ontap import HostConnection
    from netapp_ontap.resources import FcpService

    with HostConnection("<mgmt-ip>", username="admin", password="password", verify=False):
        resource = FcpService()
        resource.svm.name = "svm1"
        resource.post(hydrate=True)
        print(resource)

Try it out

    FcpService(
        {
            "svm": {
                "uuid": "5c659d90-c01a-11e8-88ed-005056bbb24b",
                "name": "svm1",
                "_links": {
                    "self": {"href": "/api/svm/svms/5c659d90-c01a-11e8-88ed-005056bbb24b"}
                },
            },
            "target": {"name": "20:00:00:50:56:bb:b2:4b"},
            "enabled": True,
            "_links": {
                "self": {
                    "href": "/api/protocols/san/fcp/services/5c659d90-c01a-11e8-88ed-005056bbb24b"
                }
            },
        }
    )

### Retrieving FC Protocol services for all SVMs in the cluster

    from netapp_ontap import HostConnection
    from netapp_ontap.resources import FcpService

    with HostConnection("<mgmt-ip>", username="admin", password="password", verify=False):
        print(list(FcpService.get_collection()))

Try it out

    [
        FcpService(
            {
                "svm": {
                    "uuid": "5c659d90-c01a-11e8-88ed-005056bbb24b",
                    "name": "svm1",
                    "_links": {
                        "self": {
                            "href": "/api/svm/svms/5c659d90-c01a-11e8-88ed-005056bbb24b"
                        }
                    },
                },
                "_links": {
                    "self": {
                        "href": "/api/protocols/san/fcp/services/5c659d90-c01a-11e8-88ed-005056bbb24b"
                    }
                },
            }
        ),
        FcpService(
            {
                "svm": {
                    "uuid": "6011f874-c01a-11e8-88ed-005056bbb24b",
                    "name": "svm2",
                    "_links": {
                        "self": {
                            "href": "/api/svm/svms/6011f874-c01a-11e8-88ed-005056bbb24b"
                        }
                    },
                },
                "_links": {
                    "self": {
                        "href": "/api/protocols/san/fcp/services/6011f874-c01a-11e8-88ed-005056bbb24b"
                    }
                },
            }
        ),
    ]

### Retrieving details for a specific FC Protocol service

The FC Protocol service is identified by the UUID of its SVM.

    from netapp_ontap import HostConnection
    from netapp_ontap.resources import FcpService

    with HostConnection("<mgmt-ip>", username="admin", password="password", verify=False):
        resource = FcpService(**{"svm.uuid": "5c659d90-c01a-11e8-88ed-005056bbb24b"})
        resource.get()
        print(resource)

Try it out

    FcpService(
        {
            "svm": {
                "uuid": "5c659d90-c01a-11e8-88ed-005056bbb24b",
                "name": "svm1",
                "_links": {
                    "self": {"href": "/api/svm/svms/5c659d90-c01a-11e8-88ed-005056bbb24b"}
                },
            },
            "target": {"name": "20:00:00:50:56:bb:b2:4b"},
            "enabled": True,
            "_links": {
                "self": {
                    "href": "/api/protocols/san/fcp/services/5c659d90-c01a-11e8-88ed-005056bbb24b"
                }
            },
        }
    )

### Disabling an FC Protocol service

Disabling an FC Protocol service shuts down all active FC Protocol logins for the SVM and prevents new FC Protocol logins.
The FC Protocol service to update is identified by the UUID of its SVM.

    from netapp_ontap import HostConnection
    from netapp_ontap.resources import FcpService

    with HostConnection("<mgmt-ip>", username="admin", password="password", verify=False):
        resource = FcpService(**{"svm.uuid": "5c659d90-c01a-11e8-88ed-005056bbb24b"})
        resource.enabled = False
        resource.patch()

You can retrieve the FC Protocol service to confirm the change.
In this example, the `fields` query parameter is used to limit the response to the `enabled` property and FC Protocol service identifiers.

    from netapp_ontap import HostConnection
    from netapp_ontap.resources import FcpService

    with HostConnection("<mgmt-ip>", username="admin", password="password", verify=False):
        resource = FcpService(**{"svm.uuid": "5c659d90-c01a-11e8-88ed-005056bbb24b"})
        resource.get(fields="enabled")
        print(resource)

Try it out

    FcpService(
        {
            "svm": {
                "uuid": "5c659d90-c01a-11e8-88ed-005056bbb24b",
                "name": "svm1",
                "_links": {
                    "self": {"href": "/api/svm/svms/5c659d90-c01a-11e8-88ed-005056bbb24b"}
                },
            },
            "enabled": False,
            "_links": {
                "self": {
                    "href": "/api/protocols/san/fcp/services/5c659d90-c01a-11e8-88ed-005056bbb24b"
                }
            },
        }
    )

### Deleting an FC Protocol service

The FC Protocol service must be disabled before it can be deleted.
The FC Protocol service to delete is identified by the UUID of its SVM.

    from netapp_ontap import HostConnection
    from netapp_ontap.resources import FcpService

    with HostConnection("<mgmt-ip>", username="admin", password="password", verify=False):
        resource = FcpService(**{"svm.uuid": "5c659d90-c01a-11e8-88ed-005056bbb24b"})
        resource.delete()

## Classes

`class FcpService (*args, **kwargs)`

  A Fibre Channel (FC) Protocol service defines the properties of the FC Protocol target for an SVM. There can be at most one FC Protocol service for an SVM. An SVM's FC Protocol service must be created before FC Protocol initiators can login to the SVM.
  A FC Protocol service is identified by the UUID of its SVM.

  Initialize the instance of the resource.

  Any keyword arguments are set on the instance as properties. For example, if the class was named 'MyResource', then this statement would be true:

      MyResource(name='foo').name == 'foo'

  ## Args

  `*args`
    Each positional argument represents a parent key as used in the URL of the object. That is, each value will be used to fill in a segment of the URL which refers to some parent object. The order of these arguments must match the order they are specified in the URL, from left to right.
  `**kwargs`
    each entry will have its key set as an attribute name on the instance and its value will be the value of that attribute.

  ### Ancestors

  - Resource

  ### Static methods

  `def count_collection(*args, connection: HostConnection = None, **kwargs) -> int`

    Retrieves FC Protocol services.

    ### Expensive properties

    There is an added cost to retrieving values for these properties. They are not included by default in GET results and must be explicitly requested using the `fields` query parameter. See `Requesting specific fields` to learn more. * `statistics.*` * `metric.*`

    ### Related ONTAP commands

    - `vserver fcp show`

    ### Learn more

    - `DOC /protocols/san/fcp/services`

    Fetch a count of all objects of this type from the host.

    This calls GET on the object to determine the number of records. It is more efficient than calling get_collection() because it will not construct any objects. Query parameters can be passed in as kwargs to determine a count of objects that match some filtered criteria.

    ## Args

    `*args`
      Each entry represents a parent key which is used to build the path to the child object. If the URL definition were /api/foos/{foo.name}/bars, then to get the count of bars for a particular foo, the foo.name value should be passed.
    `connection`
      The `HostConnection` object to use for this API call. If unset, tries to use the connection which is set globally for the library or from the current context.
    `**kwargs`
      Any key/value pairs passed will be sent as query parameters to the host. These query parameters can affect the count. A return_records query param will be ignored.

    ## Returns

    On success, returns an integer count of the objects of this type. On failure, returns -1.

    ## Raises

    `NetAppRestError`: If the API call returned a status code >= 400, or if there is no connection available to use either passed in or on the library.

  `def delete_collection(*args, body: typing.Union = None, connection: HostConnection = None, **kwargs) -> NetAppResponse`

    Deletes an FC Protocol service. An FC Protocol service must be disabled before it can be deleted.

    ### Related ONTAP commands

    - `vserver fcp delete`

    ### Learn more

    - `DOC /protocols/san/fcp/services`

    Delete all objects in a collection which match the given query.

    All records on the host which match the query will be deleted.

    ## Args

    `*args`
      Each entry represents a parent key which is used to build the path to the child object. If the URL definition were /api/foos/{foo.name}/bars, then to delete the collection of bars for a particular foo, the foo.name value should be passed.
    `body`
      The body of the delete request. This could be a Resource instance or a dictionary object.
    `connection`
      The `HostConnection` object to use for this API call. If unset, tries to use the connection which is set globally for the library or from the current context.
    `**kwargs`
      Any key/value pairs passed will be sent as query parameters to the host. Only resources matching this query will be patched.

    ## Returns

    A `NetAppResponse` object containing the details of the HTTP response.

    ## Raises

    `NetAppRestError`: If the API call returned a status code >= 400

  `def find(*args, connection: HostConnection = None, **kwargs) -> Resource`

    Retrieves FC Protocol services.

    ### Expensive properties

    There is an added cost to retrieving values for these properties. They are not included by default in GET results and must be explicitly requested using the `fields` query parameter. See `Requesting specific fields` to learn more. * `statistics.*` * `metric.*`

    ### Related ONTAP commands

    - `vserver fcp show`

    ### Learn more

    - `DOC /protocols/san/fcp/services`

    Find an instance of an object on the host given a query.

    The host will be queried with the provided key/value pairs to find a matching resource. If 0 are found, None will be returned. If more than 1 is found, an error will be raised or returned. If there is exactly 1 matching record, then it will be returned.

    ## Args

    `*args`
      Each entry represents a parent key which is used to build the path to the child object. If the URL definition were /api/foos/{foo.name}/bars, then to find a bar for a particular foo, the foo.name value should be passed.
    `connection`
      The `HostConnection` object to use for this API call. If unset, tries to use the connection which is set globally for the library or from the current context.
    `**kwargs`
      Any key/value pairs passed will be sent as query parameters to the host.

    ## Returns

    A `Resource` object containing the details of the object or None if no matches were found.

    ## Raises

    `NetAppRestError`: If the API call returned more than 1 matching resource.

  `def get_collection(*args, connection: HostConnection = None, max_records: int = None, **kwargs) -> typing.Iterable`

    Retrieves FC Protocol services.

    ### Expensive properties

    There is an added cost to retrieving values for these properties. They are not included by default in GET results and must be explicitly requested using the `fields` query parameter. See `Requesting specific fields` to learn more. * `statistics.*` * `metric.*`

    ### Related ONTAP commands

    - `vserver fcp show`

    ### Learn more

    - `DOC /protocols/san/fcp/services`

    Fetch a list of all objects of this type from the host.

    This is a lazy fetch, making API calls only as necessary when the result of this call is iterated over. For instance, if max_records is set to 5, then iterating over the collection causes an API call to be sent to the server once for every 5 records. If the client stops iterating before getting to the 6th record, then no additional API calls are made.

    ## Args

    `*args`
      Each entry represents a parent key which is used to build the path to the child object. If the URL definition were /api/foos/{foo.name}/bars, then to get the collection of bars for a particular foo, the foo.name value should be passed.
    `connection`
      The `HostConnection` object to use for this API call. If unset, tries to use the connection which is set globally for the library or from the current context.
    `max_records`
      The maximum number of records to return per call
    `**kwargs`
      Any key/value pairs passed will be sent as query parameters to the host.

    ## Returns

    A list of `Resource` objects

    ## Raises

    `NetAppRestError`: If there is no connection available to use either passed in or on the library. This would be not be raised when get_collection() is called, but rather when the result is iterated.

  `def patch_collection(body: dict, *args, connection: HostConnection = None, **kwargs) -> NetAppResponse`

    Updates an FC Protocol service.

    ### Related ONTAP commands

    - `vserver fcp modify`
    - `vserver fcp start`
    - `vserver fcp stop`

    ### Learn more

    - `DOC /protocols/san/fcp/services`

    Patch all objects in a collection which match the given query.

    All records on the host which match the query will be patched with the provided body.

    ## Args

    `body`
      A dictionary of name/value pairs to set on all matching members of the collection.
    `*args`
      Each entry represents a parent key which is used to build the path to the child object. If the URL definition were /api/foos/{foo.name}/bars, then to patch the collection of bars for a particular foo, the foo.name value should be passed.
    `connection`
      The `HostConnection` object to use for this API call. If unset, tries to use the connection which is set globally for the library or from the current context.
    `**kwargs`
      Any key/value pairs passed will be sent as query parameters to the host. Only resources matching this query will be patched.

    ## Returns

    A `NetAppResponse` object containing the details of the HTTP response.

    ## Raises

    `NetAppRestError`: If the API call returned a status code >= 400

  ### Methods

  `def delete(self, body: typing.Union = None, poll: bool = True, poll_interval: typing.Union = None, poll_timeout: typing.Union = None, **kwargs) -> NetAppResponse`

    Deletes an FC Protocol service. An FC Protocol service must be disabled before it can be deleted.

    ### Related ONTAP commands

    - `vserver fcp delete`

    ### Learn more

    - `DOC /protocols/san/fcp/services`

    Send a deletion request to the host for this object.

    ## Args

    `body`
      The body of the delete request. This could be a Resource instance or a dictionary object.
    `poll`
      If set to True, the call will not return until the asynchronous job on the host has completed. Has no effect if the host did not return a job response.
    `poll_interval`
      If the operation returns a job, this specifies how often to query the job for updates.
    `poll_timeout`
      If the operation returns a job, this specifies how long to continue monitoring the job's status for completion.
    `**kwargs`
      Any key/value pairs passed will be sent as query parameters to the host.

    ## Returns

    A `NetAppResponse` object containing the details of the HTTP response.

    ## Raises

    `NetAppRestError`: If the API call returned a status code >= 400

  `def get(self, **kwargs) -> NetAppResponse`

    Retrieves an FC Protocol service.

    ### Related ONTAP commands

    - `vserver fcp show`

    ### Learn more

    - `DOC /protocols/san/fcp/services`

    Fetch the details of the object from the host.

    Requires the keys to be set (if any). After returning, new or changed properties from the host will be set on the instance.

    ## Returns

    A `NetAppResponse` object containing the details of the HTTP response.

    ## Raises

    `NetAppRestError`: If the API call returned a status code >= 400

  `def patch(self, hydrate: bool = False, poll: bool = True, poll_interval: typing.Union = None, poll_timeout: typing.Union = None, **kwargs) -> NetAppResponse`

    Updates an FC Protocol service.

    ### Related ONTAP commands

    - `vserver fcp modify`
    - `vserver fcp start`
    - `vserver fcp stop`

    ### Learn more

    - `DOC /protocols/san/fcp/services`

    Send the difference in the object's state to the host as a modification request.

    Calculates the difference in the object's state since the last time we interacted with the host and sends this in the request body.

    ## Args

    `hydrate`
      If set to True, after the response is received from the call, a a GET call will be made to refresh all fields of the object.
    `poll`
      If set to True, the call will not return until the asynchronous job on the host has completed. Has no effect if the host did not return a job response.
    `poll_interval`
      If the operation returns a job, this specifies how often to query the job for updates.
    `poll_timeout`
      If the operation returns a job, this specifies how long to continue monitoring the job's status for completion.
    `**kwargs`
      Any key/value pairs passed will normally be sent as query parameters to the host. If any of these pairs are parameters that are sent as formdata then only parameters of that type will be accepted and all others will be discarded.

    ## Returns

    A `NetAppResponse` object containing the details of the HTTP response.

    ## Raises

    `NetAppRestError`: If the API call returned a status code >= 400

  `def post(self, hydrate: bool = False, poll: bool = True, poll_interval: typing.Union = None, poll_timeout: typing.Union = None, **kwargs) -> NetAppResponse`

    Creates an FC Protocol service.

    ### Required properties

    - `svm.uuid` or `svm.name` - Existing SVM in which to create the FC Protocol service.

    ### Related ONTAP commands

    - `vserver fcp create`

    ### Learn more

    - `DOC /protocols/san/fcp/services`

    Send this object to the host as a creation request.

    ## Args

    `hydrate`
      If set to True, after the response is received from the call, a a GET call will be made to refresh all fields of the object.
    `poll`
      If set to True, the call will not return until the asynchronous job on the host has completed. Has no effect if the host did not return a job response.
    `poll_interval`
      If the operation returns a job, this specifies how often to query the job for updates.
    `poll_timeout`
      If the operation returns a job, this specifies how long to continue monitoring the job's status for completion.
    `**kwargs`
      Any key/value pairs passed will normally be sent as query parameters to the host. If any of these pairs are parameters that are sent as formdata then only parameters of that type will be accepted and all others will be discarded.

    ## Returns

    A `NetAppResponse` object containing the details of the HTTP response.

    ## Raises

    `NetAppRestError`: If the API call returned a status code >= 400

  ### Inherited members

  - `Resource`:
    - `from_dict`
    - `get_collection_url`
    - `get_connection`
    - `instance_location`
    - `path_keys`
    - `poll`
    - `set_connection`
    - `to_dict`
`class FcpServiceSchema (*, only: typing.Union = None, exclude: typing.Union = (), many: bool = False, context: typing.Dict = None, load_only: typing.Union = (), dump_only: typing.Union = (), partial: typing.Union = False, unknown: str = None)`

  The fields of the FcpService object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC

  ### Class variables

  `enabled GET POST PATCH`

    The administrative state of the FC Protocol service. The FC Protocol service can be disabled to block all FC Protocol connectivity to the SVM.
    This is optional in POST and PATCH. The default setting is true (enabled) in POST.

  `links GET`

    The links field of the fcp_service.

  `metric GET POST PATCH`

    The metric field of the fcp_service.

  `statistics GET POST PATCH`

    The statistics field of the fcp_service.

  `svm GET POST PATCH`

    The svm field of the fcp_service.

  `target GET POST PATCH`

    The target field of the fcp_service.